@@ -2,7 +2,7 @@
 /* gtk-based file finding and munging command */
 /*
   gtkfind - a graphical "find" program
-  Copyright (C) 1998  Matthew Grossman <mattg@oz.net>
+  Copyright (C) 1999  Matthew Grossman <mattg@oz.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 /*********************/
 /* globals           */
 
-static char *version = "gtkfind v0.9";
+static char *version = "gtkfind v1.0.1";
 
 static int run_only_once = 0; /* do we run only once? */
 
@@ -38,6 +38,7 @@ static int gid = -1;
 
 static char *window_output_text = NULL;
 
+#define OUTPUT_FONT "-misc-fixed-medium-r-normal--13-120-75-75-c-70-iso8859-1"
 
 /*********************/
 /* functions         */
@@ -69,7 +70,7 @@ main(int argc, char *argv[])
   
   make_widgets();
 
-  g_set_message_handler(gtk_print1);
+  g_set_message_handler((GPrintFunc)gtk_print1);
   
   gtk_main();
   
@@ -131,8 +132,9 @@ find(gpointer *find_button, gpointer *pattern)
   normal_cursor = gdk_cursor_new(GDK_TOP_LEFT_ARROW);
 
   gtk_widget_hide(GTK_WIDGET(find_button));
-  gdk_window_set_cursor(stop_button->window, normal_cursor);
   gtk_widget_show(stop_button);
+  gdk_window_set_cursor(stop_button->window, normal_cursor);
+
 
   if(getcwd(cwd, MAXPATHLEN) == NULL) {
     print_error("getcwd: %s", strerror(errno));
@@ -156,9 +158,6 @@ find(gpointer *find_button, gpointer *pattern)
   
   if(get_flag(PRINT_TO_WINDOW_P))
     make_output_window();
-  
-  if(run_only_once)
-    gtk_exit(0);
 
  DONE:
   if(search_directory)
@@ -349,7 +348,8 @@ substitute_filename(char *target, char **registers)
   return(rv);
 }
       
-char *get_search_directory(GtkWidget *directory)
+char *
+get_search_directory(GtkWidget *directory)
      /* return the search directory, if it is null return "/", if it
 	has a ~  or a . expand it */
 {
@@ -522,6 +522,9 @@ output_toplevel_delete()
   gtk_widget_destroy(GTK_WIDGET(output_toplevel));
   output_toplevel = NULL;
   reset_window_output_text();
+
+  if(run_only_once)
+    gtk_exit(EXIT_SUCCESS);
   
   return;
 }
@@ -540,9 +543,9 @@ make_output_window()
   static int c_width = 0;
 
   if(!output_font) {
-    output_font = gdk_font_load("fixed");
+    output_font = gdk_font_load(OUTPUT_FONT);
     if(!output_font) {
-      print_error("Unable to load font fixed\n");
+      print_error("Unable to load output font %s\n", OUTPUT_FONT);
       goto DONE;
     }
     c_width = gdk_char_width(output_font, ' '); /* fixed width font */
@@ -695,25 +698,14 @@ match_atime(time_t t)
   /*  time_t user_atime = 0; */
   int rv = 0;
 
-  if(!get_flag(ATIME_ET_P) && !get_flag(ATIME_EQ_P) && !get_flag(ATIME_LT_P)) {
+  if((!get_flag(ATIME_ET_P) && !get_flag(ATIME_EQ_P) &&
+      !get_flag(ATIME_LT_P)) ||
+     (get_flag(ATIME_ET_P) && t < global_atime) ||
+     (get_flag(ATIME_EQ_P) && t == global_atime) ||
+     (get_flag(ATIME_LT_P) && t > global_atime)) {
     rv = 1;
-    goto DONE;
   }
 
-  if(get_flag(ATIME_ET_P) && t < global_atime) {
-    rv = 1;
-    goto DONE;
-  }
-  else if(get_flag(ATIME_EQ_P) && t == global_atime) {
-    rv = 1;
-    goto DONE;
-  }
-  else if(get_flag(ATIME_LT_P) && t > global_atime) {
-    rv = 1;
-    goto DONE;
-  }
-
- DONE:
   return(rv);
 }
 
@@ -722,26 +714,14 @@ match_ctime(time_t t)
 {
   int rv = 0;
 
-  if(!get_flag(CTIME_ET_P) && !get_flag(CTIME_EQ_P) && !get_flag(CTIME_LT_P)) {
+  if((!get_flag(CTIME_ET_P) && !get_flag(CTIME_EQ_P) &&
+      !get_flag(CTIME_LT_P)) ||
+     (get_flag(CTIME_ET_P) && t < global_ctime) ||
+     (get_flag(CTIME_EQ_P) && t == global_ctime) ||
+     (get_flag(CTIME_LT_P) && t > global_ctime)) {
     rv = 1;
-    goto DONE;
   }
 
-
-  if(get_flag(CTIME_ET_P) && t < global_ctime) {
-    rv = 1;
-    goto DONE;
-  }
-  else if(get_flag(CTIME_EQ_P) && t == global_ctime) {
-    rv = 1;
-    goto DONE;
-  }
-  else if(get_flag(CTIME_LT_P) && t > global_ctime) {
-    rv = 1;
-    goto DONE;
-  }
-
- DONE:
   return(rv);
 }
 
@@ -750,26 +730,14 @@ match_mtime(time_t t)
 {
   int rv = 0;
 
-  if(!get_flag(MTIME_ET_P) && !get_flag(MTIME_EQ_P) && !get_flag(MTIME_LT_P)) {
+  if((!get_flag(MTIME_ET_P) && !get_flag(MTIME_EQ_P) &&
+      !get_flag(MTIME_LT_P)) ||
+     (get_flag(MTIME_ET_P) && t < global_mtime) ||
+     (get_flag(MTIME_EQ_P) && t == global_mtime) ||
+     (get_flag(MTIME_LT_P) && t > global_mtime)) {
     rv = 1;
-    goto DONE;
   }
 
-
-  if(get_flag(MTIME_ET_P) && t < global_mtime) {
-    rv = 1;
-    goto DONE;
-  }
-  else if(get_flag(MTIME_EQ_P) && t == global_mtime) {
-    rv = 1;
-    goto DONE;
-  }
-  else if(get_flag(MTIME_LT_P) && t > global_mtime) {
-    rv = 1;
-    goto DONE;
-  }
-
- DONE:
   return(rv);
 }
 
@@ -892,9 +860,25 @@ match_contents(char *full_file_name, struct stat sbuf, char *content_string)
   char *s = NULL;
   int rv = 0;
   int i = 0;
+  char buffer[MAXPATHLEN];
+  int size = 0;
+  struct stat symlink;
 
   /* we will only match text in a regular file (or from a symbolic link) */
-  if((sbuf.st_mode & S_IFMT) != S_IFREG && (sbuf.st_mode & S_IFMT) != S_IFLNK)
+  /* if we are dealing with a symbolic link we must make sure that it
+     points to a regular file */
+  if((sbuf.st_mode & S_IFMT) == S_IFLNK) {
+    size = readlink(full_file_name, buffer, MAXPATHLEN);
+    if(!size) {
+      print_error("match_contents: Can't readlink on %s", full_file_name);
+      goto ERROR;
+    }
+    buffer[size] = '\0'; /* filename not guaranteed to be NUL terminated */
+    stat(buffer, &symlink);
+    if((symlink.st_mode & S_IFMT) != S_IFREG)
+      goto DONE;
+  }
+  else if((sbuf.st_mode & S_IFMT) != S_IFREG)
     goto DONE;
 
   fp = fopen(full_file_name, "r");
