@@ -1,6 +1,6 @@
 /* save.h */
 /* header file for save.c */
-/* Copyright (C) 1998 Matthew Grossman <mattg@oz.net>
+/* Copyright (C) 1999 Matthew Grossman <mattg@oz.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,8 +29,12 @@
 #include<pwd.h>
 #include<grp.h>
 #include<sys/types.h>
+#include<sys/stat.h>
 #include<errno.h>
 #include<time.h>
+#ifdef TM_IN_SYS_TIME
+#include<sys/time.h>
+#endif
 
 #include"util.h"
 #include"flags.h"
