@@ -2,7 +2,7 @@
 /* gtkfind code for making and displaying the interface, callbacks... */
 /*
   gtkfind - a graphical "find" program
-  Copyright (C) 1998  Matthew Grossman <mattg@oz.net>
+  Copyright (C) 1999  Matthew Grossman <mattg@oz.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,6 +21,14 @@
 
 #include"widgets.h"
 
+
+/* the path to xterm */
+#define CONFIG_XTERM "/usr/X11R6/bin/xterm"
+
+/* the path to man */
+#define CONFIG_MAN "/usr/bin/man"
+
+
 /* local variables */
 
 static gfloat current_day = 0.0;
@@ -30,6 +38,7 @@ static gfloat current_hour = 0.0;
 static gfloat current_minute = 0.0;
 static gfloat current_second = 0.0;
 
+
 void
 make_widgets()
      /* make all the widgets and set them up properly */
@@ -44,9 +53,10 @@ make_widgets()
 		     GTK_SIGNAL_FUNC(quit), NULL);
   gtk_signal_connect(GTK_OBJECT(toplevel), "destroy", GTK_SIGNAL_FUNC(quit),
 		     NULL);
-  gtk_widget_show(toplevel);
 
+  
   vbox = create_vbox(toplevel);
+
   make_directory_widgets(vbox);
 
   hsep = create_hseparator(vbox);
@@ -61,7 +71,7 @@ make_widgets()
 
   make_button_widgets(vbox);
 
-  
+  gtk_widget_show(toplevel);
   return;
 }
 
@@ -146,7 +156,7 @@ make_shell_widgets(GtkWidget *parent)
   /* shell command stuff */
 
   toggle = create_toggle_button(parent, shell_command_toggle_callback, NULL,
-				FALSE, "Run a shell commmand?");
+				FALSE, "Run a shell command?");
 
   hbox = create_hbox(parent);
   label = create_label(hbox, "Shell command:");
@@ -1260,7 +1270,7 @@ clear_find_callback()
 	stuff), and not change anything else */
 {
 
-  gtk_signal_emit_by_name(GTK_OBJECT(toplevel), "foreach", reset_widget);
+  gtk_container_foreach(GTK_CONTAINER(toplevel), reset_widget, NULL);
   reset_flags();
 
   return;
@@ -1273,7 +1283,7 @@ reset_widget(GtkWidget *widget, gpointer callback_data)
   caddr_t (*reset_function)();
   
   if(GTK_IS_CONTAINER(widget))
-    gtk_signal_emit_by_name(GTK_OBJECT(widget), "foreach", reset_widget);
+    gtk_container_foreach(GTK_CONTAINER(widget), reset_widget, NULL);
   
   reset_function = gtk_object_get_data(GTK_OBJECT(widget), "reset_yourself");
   if(reset_function)
